@@ -26,9 +26,9 @@ import sys
 import time
 import yaml
 
-from notification_engine import NotificationEngine
-from periodic_engine import PeriodicEngine
-from retry_engine import RetryEngine
+from monasca_notification.notification_engine import NotificationEngine
+from monasca_notification.periodic_engine import PeriodicEngine
+from monasca_notification.retry_engine import RetryEngine
 
 log = logging.getLogger(__name__)
 processors = []  # global list to facilitate clean signal handling
@@ -102,6 +102,14 @@ def main(argv=None):
     config = yaml.safe_load(open(config_file, 'r'))
 
     # Setup logging
+    try:
+        if config['logging']['raise_exceptions'] is True:
+            logging.raiseExceptions = True
+        else:
+            logging.raiseExceptions = False
+    except KeyError:
+        logging.raiseExceptions = False
+        pass
     logging.config.dictConfig(config['logging'])
 
     for proc in range(0, config['processors']['notification']['number']):
