@@ -15,14 +15,20 @@
 
 import json
 import mock
-import Queue
 import requests
 import time
 import unittest
 
-from monasca_notification.notification import Notification
+import six
+
+from monasca_notification import notification as m_notification
 from monasca_notification.plugins import pagerduty_notifier
 
+if six.PY2:
+    import Queue as queue
+else:
+    import queue
+
 
 def alarm(metrics):
     return {"tenantId": "0",
@@ -45,7 +51,7 @@ class requestsResponse(object):
 
 class TestWebhook(unittest.TestCase):
     def setUp(self):
-        self.trap = Queue.Queue()
+        self.trap = queue.Queue()
         self.pagerduty_config = {'timeout': 50, 'key': 'foobar'}
 
     def tearDown(self):
@@ -144,13 +150,13 @@ class TestWebhook(unittest.TestCase):
 
         alarm_dict = alarm(metric)
 
-        notification = Notification(0,
-                                    'pagerduty',
-                                    'pagerduty notification',
-                                    'ABCDEF',
-                                    0,
-                                    0,
-                                    alarm_dict)
+        notification = m_notification.Notification(0,
+                                                   'pagerduty',
+                                                   'pagerduty notification',
+                                                   'ABCDEF',
+                                                   0,
+                                                   0,
+                                                   alarm_dict)
 
         self.trap.put(pagerduty.send_notification(notification))
 
